@@ -25,7 +25,7 @@ pub fn solve(input: &mut Input) -> Result<Word, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let example_input = "cpy 2 a
 tgl a
