@@ -99,7 +99,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!(
             "[1518-11-01 00:00] Guard #10 begins shift
